==> image-saas-client-0.0.160-sources.jar: com/xforceplus/imagesaas/controller/StatementBillFeignApi.java <==
package com.xforceplus.imagesaas.controller;


/**
 * ${table.comment}feign客户端
 *
 * @author ultraman
 * @date 2021-07-05
 */
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.GetMapping;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import org.springframework.web.bind.annotation.*;
import com.baomidou.mybatisplus.extension.api.R;
import com.baomidou.mybatisplus.core.toolkit.StringUtils;
import com.xforceplus.imagesaas.entity.StatementBill;
import lombok.AllArgsConstructor;
import org.springframework.stereotype.Controller;
import java.util.List;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;


@FeignClient(name = "image-saas")
public interface StatementBillFeignApi {

  /**
   * 通过id查询${table.comment}
   * @param  id
   * @return R
   */
  @GetMapping("/statementBill/get/{id}" )
  public R getById(@PathVariable Long id);

  /**
   * 新增${table.comment}
   * @param statementBill ${table.comment}
   * @return R
   */
  @PostMapping("/statementBill/add")
  public R save(@RequestBody StatementBill statementBill);

  /**
   * 修改${table.comment}
   * @param statementBill ${table.comment}
   * @return R
   */
  @PostMapping("/statementBill/update")
  public R updateById(@RequestBody StatementBill statementBill);

  /**
   * 通过id删除${table.comment}
   * @param  id
   * @return R
   */
  @DeleteMapping("/statementBill/del/{id}" )
  public R removeById(@PathVariable Long id);

}

==> image-saas-client-0.1.193-sources.jar: com/xforceplus/imagesaas/controller/StatementBillFeignApi.java <==
package com.xforceplus.imagesaas.controller;


/**
 * 对账单feign客户端
 *
 * @author ultraman
 * @date 2023-05-12
 */
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.GetMapping;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import org.springframework.web.bind.annotation.*;
import com.baomidou.mybatisplus.extension.api.R;
import org.apache.commons.lang3.StringUtils;
import com.xforceplus.imagesaas.entity.StatementBill;
import lombok.AllArgsConstructor;
import org.springframework.stereotype.Controller;
import java.util.List;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;


@FeignClient(name = "image-saas")
public interface StatementBillFeignApi {

  /**
   * 通过id查询对账单
   * @param  id
   * @return R
   */
  @GetMapping("/statementBill/get/{id}" )
  public R getById(@PathVariable Long id);

  /**
   * 新增对账单
   * @param statementBill 对账单
   * @return R
   */
  @PostMapping("/statementBill/add")
  public R save(@RequestBody StatementBill statementBill);

  /**
   * 修改对账单
   * @param statementBill 对账单
   * @return R
   */
  @PostMapping("/statementBill/update")
  public R updateById(@RequestBody StatementBill statementBill);

  /**
   * 通过id删除对账单
   * @param  id
   * @return R
   */
  @DeleteMapping("/statementBill/del/{id}" )
  public R removeById(@PathVariable Long id);

}
